@@ -78,7 +78,8 @@ class Blueprint(Base):
     name: str = Field(..., description="Package name")
     version: str = Field(..., description="Package name")
     homepage: Optional[AnyHttpUrl] = Field(None, description="Upstream project homepage")
-    revision: int = Field(1, description="Package revision")
+    revision: int = Field(1, description="Package revision", ge=1)
+    epoch: int = Field(0, description="Package epoch", ge=0)
     arch: Architecture = Field("amd64", description="Package architecture")
     summary: str = Field(..., description="Package short description, one line only")
     description: str = Field("", description="Package description")
@@ -93,6 +94,10 @@ class Blueprint(Base):
     recommends: List[str] = Field(
         default_factory=list, description="Package recommended dependencies"
     )
+    replaces: List[str] = Field(
+        default_factory=list,
+        description="List of packages replaced by this package",
+    )
     conflicts: List[str] = Field(
         default_factory=list,
         description="Conflicting packages, for more information read "
